ZipMap

Trait ZipMap 

pub trait ZipMap<T> {
    // Required method
    fn zip_map(self, other: Self, f: impl Fn(T, T) -> T) -> Self;
}

Required Methods

fn zip_map(self, other: Self, f: impl Fn(T, T) -> T) -> Self

Zips the components of self and other, applying f, and returning the results as Self.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl ZipMap<f32> for Vec3

Source

fn zip_map(self, other: Self, f: impl Fn(f32, f32) -> f32) -> Self

Zips the components of self and other, applying f, and returning the results as Self.

Implementors